package com.example.multitenant

import io.gatling.core.Predef._
import io.gatling.http.Predef._

import scala.concurrent.duration.DurationInt
import scala.util.Random

class MultiTenantSimulation extends Simulation with MultiTenantTestConfiguration {

  val getDocument = exec(http("Get document").get("/${dbPrefix}${dbNumber}/${collectionPrefix}${collectionNumber}/${documentId}"))

  val mainFeeder = Iterator.continually(Map("dbPrefix" -> dbPrefix, "collectionPrefix" -> collectionPrefix))

  val variablesFeeder = Iterator.continually(
    Map("dbNumber" -> Random.nextInt(numberOfDbs),
      "collectionNumber" -> Random.nextInt(numberOfCollections),
      "documentId" -> Random.nextInt(numberOfDocuments)
    )
  )

  val reader = scenario("Read data")
    .feed(mainFeeder)
    .during(testDuration) {
      feed(variablesFeeder).exec(getDocument.pause(200 millis, 1000 millis))
    }

  setUp(reader.inject(rampUsers(numberOfReaders).over(testDuration.div(10)))).protocols(http.baseURL(baseUrl))

}
